@@ -75,7 +75,7 @@ def local_method(data, method = "dNewton"):
     x0 = np.array(data["x0"])
     e = np.inf
     success = True
-    tol = 1e-6
+    tol = 1e-8
     x_defl = data["x_defl"]
     bounds = d.bounds
     max_iter = d.local_max_iter
@@ -92,7 +92,7 @@ def local_method(data, method = "dNewton"):
     if method == "dNewton":
         x,f,g,eig,success = DNewton(d.func,grad,hess,bounds,x0,max_iter,*args)
     elif type(method) == str:
-        res = minimize(d.func,x0,args = args,method = method,jac = grad,bounds = bounds, constraints = d.constr)
+        res = minimize(d.func,x0,args = args,method = method,jac = grad,bounds = bounds, constraints = d.constr, options = {"disp":True})
         x = res["x"]
         f = res["fun"]
         g = np.linalg.norm(res["jac"])
